@@ -2,7 +2,6 @@ from typing import List, Optional, Dict
 
 from dataclasses import dataclass, field
 
-from code_loader.contract.datasetclasses import ConnectionInstance
 from code_loader.contract.enums import DatasetMetadataType, LeapDataType
 
 
@@ -39,6 +38,12 @@ class DecoderInstance:
     type: LeapDataType
 
 
+@dataclass
+class HeatmapBlockInstance:
+    name: str
+    labels: List[str]
+
+
 @dataclass
 class DatasetSetup:
     preprocess: DatasetPreprocess
@@ -46,6 +51,7 @@ class DatasetSetup:
     metadata: List[DatasetMetadataInstance]
     outputs: List[DatasetOutputInstance]
     decoders: List[DecoderInstance]
+    heatmap_blocks: List[HeatmapBlockInstance]
 
 
 @dataclass
