@@ -1,11 +1,12 @@
-from typing import Callable, List, Optional, Dict, Any, Union
+from typing import Callable, List, Optional, Dict, Any
 
 import numpy as np  # type: ignore
 
 from code_loader.contract.datasetclasses import SectionCallableInterface, InputHandler, \
     GroundTruthHandler, MetadataHandler, DatasetIntegrationSetup, DecoderHandler, PreprocessResponse, \
-    PreprocessHandler, DecoderCallableInterface, ConnectionInstance
+    PreprocessHandler, DecoderCallableInterface
 from code_loader.contract.enums import DatasetMetadataType, LeapDataType
+from code_loader.contract.responsedataclasses import HeatmapBlockInstance
 from code_loader.decoders.default_decoders import DefaultDecoder, default_numeric_decoder, default_graph_decoder, \
     default_image_decoder, default_horizontal_bar_decoder, default_word_decoder, \
     default_image_mask_decoder, default_text_mask_decoder
@@ -37,15 +38,6 @@ class DatasetBinder:
         self.setup_container.decoders.append(DecoderHandler(name, decoder, type, heatmap_decoder))
         self._decoder_names.append(name)
 
-    def set_connection(self, decoder_name: Union[DefaultDecoder, str], encoder_names: List[str]) -> None:
-        if isinstance(decoder_name, DefaultDecoder):
-            decoder_name = decoder_name.value
-        assert decoder_name in self._decoder_names
-        for encoder_name in encoder_names:
-            assert encoder_name in self._encoder_names
-        
-        self.setup_container.connections.append(ConnectionInstance(decoder_name, encoder_names))
-
     def set_preprocess(self, function: Callable[[], List[PreprocessResponse]]) -> None:
         self.setup_container.preprocess = PreprocessHandler(function)
 
@@ -55,6 +47,9 @@ class DatasetBinder:
 
         self._encoder_names.append(input_name)
 
+    def set_heatmap_block(self, name: str, labels: List[str]) -> None:
+        self.setup_container.heatmap_blocks.append(HeatmapBlockInstance(name, labels))
+
     def set_ground_truth(self, function: SectionCallableInterface, gt_name: str) -> None:
         function = to_numpy_return_wrapper(function)
         self.setup_container.ground_truths.append(GroundTruthHandler(gt_name, function))
